.. rst-class:: detail

Debug
================

.. currentmodule:: compas_rrc

.. autoclass:: Debug

    
    
    .. rubric:: Methods

    .. autosummary::
        :toctree:

    
        ~Debug.__init__
        ~Debug.from_msg
        ~Debug.parse_feedback
    
    